;;
;; Par Mohamed Choubane
;;
(nouvelle-figure "Steiner")
(soit Point "A" libre 7 -5)
(soit Point "B" libre -3 -4)
(soit Point  "C" libre 1 5)
(soit Segment "AB" extrémités A B)
(soit Segment  "AC" extrémités A C)
(soit Segment  "BC" extrémités B C)
(soit Point  "I"  milieu-2pts A B)
(soit Point "J" milieu-2pts A C)
(soit Droite "d1" perpendiculaire I AB)
(soit Droite "d2"  perpendiculaire J AC)
(soit  Point "O" intersection d1 d2)
(soit Cercle "Ce" 2points O A)
(envoi I masquer)
(envoi J masquer)
(envoi d1 masquer)
(envoi d2 masquer)
(soit Droite "l1" perpendiculaire C AB)
(soit Droite "l2" perpendiculaire A BC)
(soit Point "H" intersection l1 l2)
(envoi l1 masquer)
(envoi l2 masquer)
(soit Droite "d3" 2points A B )
(soit Droite "d4" 2points A C)
(soit Droite "d5" 2points B C)
(soit Point "M" sur-courbe Ce (random:uniform))
(soit Point "M1" reflexion M d3)
(soit Point "M2" reflexion M d4)
(soit Point "M3" reflexion M d5)
(soit  Droite "d" 2points M1 M2)
(envoi d3 masquer)
(envoi d4 masquer)
(envoi d5 masquer)