((:pointColor "Red") (:pointShape "Cross") (:pointSize "Small")
 (:polygonColor "Yellow")
 (:segmentColor "Black") (:segmentStyle "Normal")
 (:halfLineColor "Black") (:halfLineStyle "Normal")
 (:lineColor "Black") (:lineStyle "Normal")
 (:circleColor "Black") (:circleStyle "Normal")
 (:arcCircleColor "Black") (:arcCircleStyle "Normal")
 (:vectorColor "Black") (:vectorStyle "Normal")
 (:locusColor "Black") (:locusStyle "Normal") (:angleColor "Black")
 (:angleStyle "Normal")
 (:scalarColor "Blue")
 (:sessionFile "session")
 (:htmlViewer "dillo ")
 (:undoLevel "5")
 (:figureName "Figure %d")
 (:figureFile "figure_")
 (:flydrawFile "figure.draw")
 (:latexFile "figure.tex")
 (:psFile "figure.ps")
 (:numericPrecision "2"))
